/*!
 * VUEX-PROMISE v2.0.0-rc.3
 * (c) 2016 crossjs
 * Released under the MIT License.
 */
'use strict';

var _extends = Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
};

function createPromise() {
  var _ref = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

  var _ref$debug = _ref.debug;
  var debug = _ref$debug === undefined ? false : _ref$debug;
  var _ref$status = _ref.status;
  var status = _ref$status === undefined ? {
    PENDING: 0,
    SUCCESS: 1,
    FAILURE: 2,
    FINALLY: 4
  } : _ref$status;
  var _ref$silent = _ref.silent;
  var silent = _ref$silent === undefined ? false : _ref$silent;

  return function (store) {
    if (debug) {
      console.log('[Promise] Vuex Promise Plugin Installed.');
    }

    store.subscribe(function (_ref2) {
      var type = _ref2.type;
      var payload = _ref2.payload;
      var meta = _ref2.meta;

      if (hasPromise(payload)) {
        store.commit({
          type: type,
          silent: silent,
          meta: _extends({}, meta, {
            promise: status.PENDING
          })
        });

        if (!Array.isArray(payload)) {
          payload = [payload];
        }

        Promise.all(payload).then(function (res) {
          store.commit({
            type: type,
            silent: silent,
            payload: payload.length === 1 ? res[0] : res,
            meta: _extends({}, meta, {
              promise: status.SUCCESS
            })
          });
          // finally
          store.commit({
            type: type,
            meta: _extends({}, meta, {
              promise: status.FINALLY
            })
          });
        }, function (err) {
          store.commit({
            type: type,
            silent: silent,
            payload: err,
            error: true,
            meta: _extends({}, meta, {
              promise: status.FAILURE
            })
          });
          // finally
          store.commit({
            type: type,
            meta: _extends({}, meta, {
              promise: status.FINALLY
            })
          });
        });
      }
    });

    function hasPromise(payload) {
      return payload && (payload.then || Array.isArray(payload) && payload.some(function (p) {
        return p && p.then;
      }));
    }
  };
}

module.exports = createPromise;